==> egov-common-1.0.3-sources.jar: com/gtis/plat/vo/PfNewsVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * 新闻
 *
 * @author HuiSeDiao
 */
public class PfNewsVo implements Serializable {

    private static final long serialVersionUID = 5494441591354783091L;

    /**
     * 新闻主键
     */
    private String newsId;
    /**
     * 新闻标题
     */
    private String newsTitle;
    /**
     * 新闻作者
     */
    private String newsAuthor;
    /**
     * 新闻日期
     */
    private Date newsDate;
    /**
     * 新闻摘要
     */
    private String newsSummary;
    /**
     * 新闻内容
     */
    private String newsContent;
    /**
     * 新闻类型
     */
    private String newsType;
    /**
     * 新闻图片
     */
    private String imageUrl;

    public String getNewsId() {
        return newsId;
    }

    public void setNewsId(String newsId) {
        this.newsId = newsId;
    }

    public String getNewsTitle() {
        return newsTitle;
    }

    public void setNewsTitle(String newsTitle) {
        this.newsTitle = newsTitle;
    }

    public String getNewsAuthor() {
        return newsAuthor;
    }

    public void setNewsAuthor(String newsAuthor) {
        this.newsAuthor = newsAuthor;
    }

    public Date getNewsDate() {
        return newsDate;
    }

    public void setNewsDate(Date newsDate) {
        this.newsDate = newsDate;
    }

    public String getNewsSummary() {
        return newsSummary;
    }

    public void setNewsSummary(String newsSummary) {
        this.newsSummary = newsSummary;
    }

    public String getNewsContent() {
        return newsContent;
    }

    public void setNewsContent(String newsContent) {
        this.newsContent = newsContent;
    }

    public String getNewsType() {
        return newsType;
    }

    public void setNewsType(String newsType) {
        this.newsType = newsType;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }
}

==> egov-common-1.1.4-sources.jar: com/gtis/plat/vo/PfNewsVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

/**
 * 新闻
 *
 * @author HuiSeDiao
 */
public class PfNewsVo implements Serializable {

    private static final long serialVersionUID = 5494441591354783091L;

    /**
     * 新闻主键
     */
    private String newsId;
    /**
     * 新闻标题
     */
    private String newsTitle;
    /**
     * 新闻作者
     */
    private String newsAuthor;
    /**
     * 新闻日期
     */
    private Date newsDate;
    /**
     * 新闻摘要
     */
    private String newsSummary;
    /**
     * 新闻内容
     */
    private String newsContent;
    /**
     * 新闻类型
     */
    private String newsType;
    /**
     * 新闻图片
     */
    private String imageUrl;

    /**
     * 新闻发布者
     */
    private String newPublisher;

    public String getNewPublisher() {
        return newPublisher;
    }

    public void setNewPublisher(String newPublisher) {
        this.newPublisher = newPublisher;
    }

    public String getNewsId() {
        return newsId;
    }

    public void setNewsId(String newsId) {
        this.newsId = newsId;
    }

    public String getNewsTitle() {
        return newsTitle;
    }

    public void setNewsTitle(String newsTitle) {
        this.newsTitle = newsTitle;
    }

    public String getNewsAuthor() {
        return newsAuthor;
    }

    public void setNewsAuthor(String newsAuthor) {
        this.newsAuthor = newsAuthor;
    }

    public Date getNewsDate() {
        return newsDate;
    }

    public void setNewsDate(Date newsDate) {
        this.newsDate = newsDate;
    }

    public String getNewsSummary() {
        return newsSummary;
    }

    public void setNewsSummary(String newsSummary) {
        this.newsSummary = newsSummary;
    }

    public String getNewsContent() {
        return newsContent;
    }

    public void setNewsContent(String newsContent) {
        this.newsContent = newsContent;
    }

    public String getNewsType() {
        return newsType;
    }

    public void setNewsType(String newsType) {
        this.newsType = newsType;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }
}
